@@ -6,7 +6,7 @@ use Mojo::Util qw(dumper);
 use DBI;
 use Carp qw(croak);
 
-our $VERSION  = '0.15';
+our $VERSION  = '0.16';
 
 use MojoX::Mysql::DB;
 use MojoX::Mysql::Result;
@@ -88,6 +88,7 @@ sub do {
 	$self->flush;
 
 	my $dbh = $self->db->id($id)->connect_master;
+	say $sql if (defined $ENV{'MOJO_MYSQL_DEBUG'} && $ENV{'MOJO_MYSQL_DEBUG'} == 1);
 	my $counter = $dbh->do($sql,undef,@_) or die $dbh->errstr;
 	my $insertid = int $dbh->{'mysql_insertid'};
 	return wantarray ? ($insertid,$counter) : $insertid;
@@ -128,6 +129,8 @@ sub query {
 		croak 'No connect server' if(ref $dbh ne 'DBI::db');
 	}
 
+	say $query if (defined $ENV{'MOJO_MYSQL_DEBUG'} && $ENV{'MOJO_MYSQL_DEBUG'} == 1);
+
 	if(defined $async){
 		my $sth = $dbh->prepare($query, {async=>1}) or croak $dbh->errstr;
 		$sth->execute(@_) or croak $dbh->errstr;
